[maemo-commits] [maemo-commits] r18096 - in projects/haf/trunk/gtk+: . gtk

From: subversion at stage.maemo.org subversion at stage.maemo.org
Date: Fri Apr 17 11:33:56 EEST 2009
Author: kris
Date: 2009-04-17 11:33:47 +0300 (Fri, 17 Apr 2009)
New Revision: 18096

Modified:
   projects/haf/trunk/gtk+/ChangeLog
   projects/haf/trunk/gtk+/gtk/gtktreeview.c
Log:
2009-04-17  Kristian Rietveld  <kris at imendio.com>

	Fixes: NB#111246 - GtkTreeView action area height in portrait
	should be n*90px

	* gtk/gtktreeview.c (hildon_tree_view_set_action_area_height): use
	90 instead of 93 px.



Modified: projects/haf/trunk/gtk+/ChangeLog
===================================================================
--- projects/haf/trunk/gtk+/ChangeLog	2009-04-17 08:19:58 UTC (rev 18095)
+++ projects/haf/trunk/gtk+/ChangeLog	2009-04-17 08:33:47 UTC (rev 18096)
@@ -1,3 +1,11 @@
+2009-04-17  Kristian Rietveld  <kris at imendio.com>
+
+	Fixes: NB#111246 - GtkTreeView action area height in portrait
+	should be n*90px
+
+	* gtk/gtktreeview.c (hildon_tree_view_set_action_area_height): use
+	90 instead of 93 px.
+
 2009-04-08  Claudio Saavedra  <csaavedra at igalia.com>
 
 	Released 2:2.12.12-1maemo13

Modified: projects/haf/trunk/gtk+/gtk/gtktreeview.c
===================================================================
--- projects/haf/trunk/gtk+/gtk/gtktreeview.c	2009-04-17 08:19:58 UTC (rev 18095)
+++ projects/haf/trunk/gtk+/gtk/gtktreeview.c	2009-04-17 08:33:47 UTC (rev 18096)
@@ -17653,12 +17653,12 @@
     {
       GList *children;
 
       /* The height in portrait mode is currently hardcoded to 93px per
        * button.
        */
       children = gtk_container_get_children (GTK_CONTAINER (tree_view->priv->action_area_box));
       hildon_tree_view_set_rows_offset (tree_view,
-                                        g_list_length (children) * 93);
+                                        g_list_length (children) * 90);
       g_list_free (children);
     }
 }
@@ -17653,12 +17653,12 @@
       GList *children;
 
-      /* The height in portrait mode is currently hardcoded to 93px per
+      /* The height in portrait mode is currently hardcoded to 90px per
        * button.
        */


More information about the maemo-commits mailing list